==> apache-wicket-6.30.0.zip: apache-wicket-6.30.0/wicket-core/src/test/java/org/apache/wicket/protocol/http/servlet/SecuredRemoteAddressRequestWrapperFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.protocol.http.servlet;

import org.apache.wicket.WicketTestCase;
import org.apache.wicket.protocol.http.mock.MockHttpServletRequest;
import org.junit.Test;

/**
 * 
 * @author Juergen Donnerstag
 */
public class SecuredRemoteAddressRequestWrapperFactoryTest extends WicketTestCase
{
	/**
	 * 
	 */
	@Test
	public void test1()
	{
		SecuredRemoteAddressRequestWrapperFactory factory = new SecuredRemoteAddressRequestWrapperFactory();
		MockHttpServletRequest request = tester.getRequest();

		request.setSecure(true);
		assertFalse(factory.needsWrapper(request));

		request.setRemoteAddr("111.222.333.444");
		assertFalse(factory.needsWrapper(request));

		request.setSecure(false);
		assertTrue(factory.needsWrapper(request));

		request.setRemoteAddr("10.222.333.444");
		assertFalse(factory.needsWrapper(request));

		request.setRemoteAddr("129.222.333.444");
		assertTrue(factory.needsWrapper(request));
	}
}

==> apache-wicket-8.17.0.zip: apache-wicket-8.17.0/wicket-core/src/test/java/org/apache/wicket/protocol/http/servlet/SecuredRemoteAddressRequestWrapperFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.protocol.http.servlet;

import org.apache.wicket.protocol.http.mock.MockHttpServletRequest;
import org.apache.wicket.util.tester.WicketTestCase;
import org.junit.Test;

/**
 * 
 * @author Juergen Donnerstag
 */
public class SecuredRemoteAddressRequestWrapperFactoryTest extends WicketTestCase
{
	/**
	 * 
	 */
	@Test
	public void test1()
	{
		SecuredRemoteAddressRequestWrapperFactory factory = new SecuredRemoteAddressRequestWrapperFactory();
		MockHttpServletRequest request = tester.getRequest();

		request.setSecure(true);
		assertFalse(factory.needsWrapper(request));

		request.setRemoteAddr("111.222.333.444");
		assertFalse(factory.needsWrapper(request));

		request.setSecure(false);
		assertTrue(factory.needsWrapper(request));

		request.setRemoteAddr("10.222.333.444");
		assertFalse(factory.needsWrapper(request));

		request.setRemoteAddr("129.222.333.444");
		assertTrue(factory.needsWrapper(request));
	}
}
